==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/et.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: et.php,v 1.15 2005/12/07 15:02:11 bigmichi1 Exp $

$text['title']          = 'S&uuml;steemi Informatsioon';

$text['vitals']         = 'System Vital';
$text['hostname']       = 'Kanooniline masinanimi';
$text['ip']             = 'Vastav IP';
$text['kversion']       = 'Kernel Versioon';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Masin elus juba';
$text['users']          = 'Hetkel kasutajaid';
$text['loadavg']        = 'Koormuse keskmised';

$text['hardware']       = 'Riistvara Informatsioon';
$text['numcpu']         = 'Protsessoreid';
$text['cpumodel']       = 'Mudel';
$text['cpuspeed']       = 'Taktsagedus MHz';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Vahem&auml;lu suurus';
$text['bogomips']       = 'S&uuml;steemi Bogomips';

$text['pci']            = 'PCI Seadmed';
$text['ide']            = 'IDE Seadmed';
$text['scsi']           = 'SCSI Seadmed';
$text['usb']            = 'USB Seadmed';

$text['netusage']       = 'V&otilde;rguteenuse kasutamine';
$text['device']         = 'Seade';
$text['received']       = 'Saadud';
$text['sent']           = 'Saadetud';
$text['errors']         = 'Vigu/H&uuml;ljatud';

$text['memusage']       = 'M&auml;lu kasutamine';
$text['phymem']         = 'F&uuml;&uuml;siline m&auml;lu';
$text['swap']           = 'Saalem&auml;lu kettal';

$text['fs']             = '&Uuml;hendatud failis&uuml;steemid';
$text['mount']          = '&Uuml;hendus';
$text['partition']      = 'Partitsioon';

$text['percent']        = 'Protsendiline h&otilde;ivatus';
$text['type']           = 'T&uuml;&uuml;p';
$text['free']           = 'Vaba';
$text['used']           = 'Kasutusel';
$text['size']           = 'Suurus';
$text['totals']         = 'Kokku';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'puudub';

$text['capacity']       = 'H&otilde;ivatus';
  
$text['template']       = 'Template';
$text['language']       = 'Keel';
$text['submit']         = 'Kehtesta';
$text['created']        = 'Looja: ';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'p&auml;eva';
$text['hours']          = 'tundi';
$text['minutes']        = 'minutit';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/et.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: et.php,v 1.19 2006/06/05 11:48:16 bigmichi1 Exp $

$text['title']          = 'S&uuml;steemi informatsioon';

$text['vitals']         = 'System Vital';
$text['hostname']       = 'Kanooniline masinanimi';
$text['ip']             = 'Vastav IP';
$text['kversion']       = 'Kerneli versioon';
$text['dversion']       = 'Distro nimi';
$text['uptime']         = 'Masin elus juba';
$text['users']          = 'Hetkel kasutajaid';
$text['loadavg']        = 'Koormuse keskmised';

$text['hardware']       = 'Riistvara informatsioon';
$text['numcpu']         = 'Protsessoreid';
$text['cpumodel']       = 'Mudel';
$text['cpuspeed']       = 'Taktsagedus MHz';
$text['busspeed']       = 'Siinikiirus';
$text['cache']          = 'Vahem&auml;lu suurus';
$text['bogomips']       = 'S&uuml;steemi BogoMIPS';

$text['pci']            = 'PCI-seadmed';
$text['ide']            = 'IDE-seadmed';
$text['scsi']           = 'SCSI-seadmed';
$text['usb']            = 'USB-seadmed';

$text['netusage']       = 'V&otilde;rguteenuse kasutamine';
$text['device']         = 'Seade';
$text['received']       = 'Saadud';
$text['sent']           = 'Saadetud';
$text['errors']         = 'Vigu/H&uuml;ljatud';

$text['memusage']       = 'M&auml;lu kasutamine';
$text['phymem']         = 'F&uuml;&uuml;siline m&auml;lu';
$text['swap']           = 'Saalem&auml;lu kettal';

$text['fs']             = '&Uuml;hendatud failis&uuml;steemid';
$text['mount']          = '&Uuml;hendus';
$text['partition']      = 'Partitsioon';

$text['percent']        = 'Protsendiline h&otilde;ivatus';
$text['type']           = 'T&uuml;&uuml;p';
$text['free']           = 'Vaba';
$text['used']           = 'Kasutusel';
$text['size']           = 'Suurus';
$text['totals']         = 'Kokku';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'puudub';

$text['capacity']       = 'H&otilde;ivatus';
  
$text['template']       = 'Mall';
$text['language']       = 'Keel';
$text['submit']         = 'Kehtesta';
$text['created']        = 'Looja:';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'p&auml;eva';
$text['hours']          = 'tundi';
$text['minutes']        = 'minutit';
  
$text['temperature']    = 'Temperatuur';
$text['voltage']        = 'Pinge';
$text['fans']           = 'Ventilaatorid';
$text['s_value']        = 'V&auml;&auml;rtus';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'H&uuml;sterees';
$text['s_limit']        = 'Limiit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + rakendused';
$text['buffers']	= 'Puhvrid';
$text['cached']		= 'Vahem&auml;lus';

$text['connections']    = 'Established Network Connections';
?>
